pub type InjectableStylesMap = IndexMap<String, Rc<InjectableStyleKind>>;Expand description
Type alias for injectable styles map, moved here to be available at the types level.
Aliased Type
pub struct InjectableStylesMap { /* private fields */ }pub type InjectableStylesMap = IndexMap<String, Rc<InjectableStyleKind>>;Type alias for injectable styles map, moved here to be available at the types level.
pub struct InjectableStylesMap { /* private fields */ }